@@ -10,7 +10,7 @@
 #' @importFrom magrittr "%>%"
 add_ep <- function(pbp) {
   out <- pbp %>% add_ep_variables()
-  message("added ep variables")
+  usethis::ui_done("added ep variables")
   return(out)
 }
 
@@ -41,10 +41,10 @@ add_air_yac_ep <- function(pbp) {
         total_home_raw_yac_epa = NA_real_,
         total_away_raw_yac_epa = NA_real_
       )
-    message("No non-NA air_yards detected. air_yac_ep variables set to NA")
+    usethis::ui_info("No non-NA air_yards detected. air_yac_ep variables set to NA")
   } else {
     out <- pbp %>% add_air_yac_ep_variables()
-    message("added air_yac_ep variables")
+    usethis::ui_done("added air_yac_ep variables")
   }
   return(out)
 }
@@ -52,7 +52,7 @@ add_air_yac_ep <- function(pbp) {
 #' @importFrom magrittr "%>%"
 add_wp <- function(pbp) {
   out <- pbp %>% add_wp_variables()
-  message("added wp variables")
+  usethis::ui_done("added wp variables")
   return(out)
 }
 
@@ -83,10 +83,10 @@ add_air_yac_wp <- function(pbp) {
         total_home_raw_yac_wpa = NA_real_,
         total_away_raw_yac_wpa = NA_real_
       )
-    message("No non-NA air_yards detected. air_yac_wp variables set to NA")
+    usethis::ui_info("No non-NA air_yards detected. air_yac_wp variables set to NA")
   } else {
     out <- pbp %>% add_air_yac_wp_variables()
-    message("added air_yac_wp variables")
+    usethis::ui_done("added air_yac_wp variables")
   }
   return(out)
 }
@@ -264,6 +264,9 @@ add_ep_variables <- function(pbp_data) {
   end_game_i <- which(missed_fg_data$half_seconds_remaining <= 0)
   missed_fg_ep_preds[end_game_i,] <- rep(0,ncol(missed_fg_ep_preds))
 
+  # if the half ends, no one scored
+  missed_fg_ep_preds[end_game_i, "No_Score"] <- 1
+
   # Get the probability of making the field goal:
   make_fg_prob <- as.numeric(mgcv::predict.bam(fg_model, newdata = pbp_data, type="response"))
 
@@ -338,24 +341,32 @@ add_ep_variables <- function(pbp_data) {
   base_ep_preds$TwoPoint_Prob <- 0
 
   # Find the indices for these types of plays:
-  extrapoint_i <- which(pbp_data$play_type == "extra_point" & pbp_data$play_type_nfl != "PAT2")
+  extrapoint_i <- which((pbp_data$play_type == "extra_point" | pbp_data$play_type_nfl == "XP_KICK") &
+                          (is.na(pbp_data$play_type_nfl) | pbp_data$play_type_nfl != "PAT2"))
   twopoint_i <- which(pbp_data$two_point_attempt == 1)
 
   #new: special case for PAT or kickoff with penalty
   #for inserting NAs
-  st_penalty_i <- which(
-    # pat
-    (dplyr::lag(pbp_data$touchdown == 1) & (dplyr::lead(pbp_data$two_point_attempt)==1 | dplyr::lead(pbp_data$extra_point_attempt)==1)) |
-      #kickoff
-      ((dplyr::lag(pbp_data$two_point_attempt)==1 | dplyr::lag(pbp_data$extra_point_attempt)==1) & dplyr::lead(pbp_data$kickoff_attempt == 1)) |
-      # kick formation + NA down
-      (stringr::str_detect(pbp_data$desc, 'Kick formation') & is.na(pbp_data$down) & pbp_data$play_type == 'no_play') |
-      (stringr::str_detect(pbp_data$desc, 'Pass formation') & is.na(pbp_data$down) & pbp_data$play_type == 'no_play') |
-      (stringr::str_detect(pbp_data$desc, 'kicks onside') & is.na(pbp_data$down) & pbp_data$play_type == 'no_play') |
-      (stringr::str_detect(pbp_data$desc, 'Offside on Free Kick') & is.na(pbp_data$down) & pbp_data$play_type == 'no_play') |
-      (stringr::str_detect(pbp_data$desc, 'TWO-POINT CONVERSION') & is.na(pbp_data$down) & pbp_data$play_type == 'no_play')
+  st_penalty_i_1 <- which(
+    # pat: prior play was TD or PAT and next play is PAT and this play isn't a td
+    (pbp_data$touchdown == 0 & (dplyr::lag(pbp_data$touchdown == 1) | dplyr::lag(pbp_data$play_type_nfl == "XP_KICK")) &
+          (dplyr::lead(pbp_data$two_point_attempt)==1 | dplyr::lead(pbp_data$extra_point_attempt)==1 | dplyr::lead(pbp_data$play_type_nfl) == "XP_KICK")) |
+      #kickoff: prior play was PAT and next play is kickoff
+      ((dplyr::lag(pbp_data$two_point_attempt)==1 | dplyr::lag(pbp_data$extra_point_attempt)==1) & dplyr::lead(pbp_data$kickoff_attempt == 1))
     )
 
+  st_penalty_i_2 <- which(
+      is.na(dplyr::lead(pbp_data$down)) &
+         # has a key term in desc
+         (((stringr::str_detect(pbp_data$desc, 'Kick formation') & is.na(pbp_data$down) & pbp_data$play_type == 'no_play') |
+             (stringr::str_detect(pbp_data$desc, 'Pass formation') & is.na(pbp_data$down) & pbp_data$play_type == 'no_play') |
+             (stringr::str_detect(pbp_data$desc, 'kicks onside') & is.na(pbp_data$down) & pbp_data$play_type == 'no_play') |
+             (stringr::str_detect(pbp_data$desc, 'Offside on Free Kick') & is.na(pbp_data$down) & pbp_data$play_type == 'no_play') |
+             (stringr::str_detect(pbp_data$desc, 'TWO-POINT CONVERSION')) &
+             # down is NA and play type no play and next play isn't a kickoff
+             is.na(pbp_data$down) & pbp_data$play_type == 'no_play' & dplyr::lead(pbp_data$kickoff_attempt) == 0))
+  )
+
   # Assign the make_fg_probs of the extra-point PATs:
   base_ep_preds$ExPoint_Prob[extrapoint_i] <- make_fg_prob[extrapoint_i]
 
@@ -382,13 +393,13 @@ add_ep_variables <- function(pbp_data) {
       is.na(pbp_data$play_type))
 
   # Now update the probabilities for missing and PATs:
-  base_ep_preds$Field_Goal[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i)] <- 0
-  base_ep_preds$Touchdown[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i)] <- 0
-  base_ep_preds$Opp_Field_Goal[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i)] <- 0
-  base_ep_preds$Opp_Touchdown[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i)] <- 0
-  base_ep_preds$Safety[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i)] <- 0
-  base_ep_preds$Opp_Safety[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i)] <- 0
-  base_ep_preds$No_Score[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i)] <- 0
+  base_ep_preds$Field_Goal[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i_1, st_penalty_i_2)] <- 0
+  base_ep_preds$Touchdown[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i_1, st_penalty_i_2)] <- 0
+  base_ep_preds$Opp_Field_Goal[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i_1, st_penalty_i_2)] <- 0
+  base_ep_preds$Opp_Touchdown[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i_1, st_penalty_i_2)] <- 0
+  base_ep_preds$Safety[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i_1, st_penalty_i_2)] <- 0
+  base_ep_preds$Opp_Safety[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i_1, st_penalty_i_2)] <- 0
+  base_ep_preds$No_Score[c(missing_i, extrapoint_i, twopoint_i, st_penalty_i_1, st_penalty_i_2)] <- 0
 
   # Rename the events to all have _Prob at the end of them:
   base_ep_preds <- dplyr::rename(base_ep_preds,
@@ -413,7 +424,13 @@ add_ep_variables <- function(pbp_data) {
                                  (1 * .data$ExPoint_Prob) + (2 * .data$TwoPoint_Prob))
 
   #just going to set these to NA bc we have no way of calculating EPA for them
-  pbp_data_ep$ExpPts[st_penalty_i] <- NA_real_
+  if (length(st_penalty_i_1) > 0) {
+    pbp_data_ep$ExpPts[st_penalty_i_1] <- NA_real_
+  }
+
+  if (length(st_penalty_i_2) > 0) {
+    pbp_data_ep$ExpPts[st_penalty_i_2] <- NA_real_
+  }
 
   #################################################################
   # Calculate EPA:
@@ -832,19 +849,35 @@ add_wp_variables <- function(pbp_data) {
       #because other team will have the ball so WP from their perspective
       #this is for backfilling WP on PATs
       wp =
-        dplyr::if_else((.data$kickoff_attempt == 0 & !(stringr::str_detect(.data$desc, 'Onside Kick')) &
-                          (stringr::str_detect(.data$desc, 'Kick formation') | stringr::str_detect(.data$desc, 'Pass formation')) & is.na(.data$down)) |
-                            stringr::str_detect(.data$desc, 'extra point') |
-                            !is.na(.data$two_point_conv_result) |
-                            !is.na(.data$extra_point_result),
-                          1 - .data$wp, .data$wp),
+        dplyr::if_else(
+          # added to deal with XP being last play of half and same team getting 2nd half kickoff
+          # make sure there's not end of half on next line with same posteam on line after that
+          !(.data$qtr == 2 & dplyr::lead(.data$qtr, 2) == 3 & dplyr::lead(.data$posteam, 2) == .data$posteam) &
+            # not a kickoff and has NA down
+          ((.data$kickoff_attempt == 0 &
+            !(stringr::str_detect(.data$desc, 'Onside Kick')) &
+            (stringr::str_detect(.data$desc, 'Kick formation') | stringr::str_detect(.data$desc, 'Pass formation')) &
+             is.na(.data$down)) |
+            # or has PAT indicators
+            stringr::str_detect(.data$desc, 'TWO-POINT CONVERSION ATTEMPT') | stringr::str_detect(.data$desc, 'extra point') |
+            !is.na(.data$two_point_conv_result) |
+            !is.na(.data$extra_point_result)),
+          1 - .data$wp, .data$wp),
       vegas_wp =
-        dplyr::if_else((.data$kickoff_attempt == 0 & !(stringr::str_detect(.data$desc, 'Onside Kick')) &
-                          (stringr::str_detect(.data$desc, 'Kick formation') | stringr::str_detect(.data$desc, 'Pass formation')) & is.na(.data$down)) |
-                            stringr::str_detect(.data$desc, 'extra point') |
-                            !is.na(.data$two_point_conv_result) |
-                            !is.na(.data$extra_point_result),
-                          1 - .data$vegas_wp, .data$vegas_wp),
+        dplyr::if_else(
+          # added to deal with XP being last play of half and same team getting 2nd half kickoff
+          # make sure there's not end of half on next line with same posteam on line after that
+          !(.data$qtr == 2 & dplyr::lead(.data$qtr, 2) == 3 & dplyr::lead(.data$posteam, 2) == .data$posteam) &
+            # not a kickoff and has NA down
+            ((.data$kickoff_attempt == 0 &
+                !(stringr::str_detect(.data$desc, 'Onside Kick')) &
+                (stringr::str_detect(.data$desc, 'Kick formation') | stringr::str_detect(.data$desc, 'Pass formation')) &
+                is.na(.data$down)) |
+               # or has PAT indicators
+               stringr::str_detect(.data$desc, 'TWO-POINT CONVERSION ATTEMPT') | stringr::str_detect(.data$desc, 'extra point') |
+               !is.na(.data$two_point_conv_result) |
+               !is.na(.data$extra_point_result)),
+          1 - .data$vegas_wp, .data$vegas_wp),
       wp = dplyr::if_else(is.na(.data$posteam), NA_real_, .data$wp),
       def_wp = 1 - .data$wp,
       home_wp = dplyr::if_else(.data$posteam == .data$home_team,
