@@ -296,260 +296,260 @@ get_pbp_nfl <- function(id, dir = NULL) {
 # hard coded 2020 regular season game ids to make sure the output of the
 # schedule scraper is not named 'invalid' if the source file not yet exists
 valid_games <- c(
-  "2020_01_HOU_KC",
-  "2020_01_SEA_ATL",
-  "2020_01_CLE_BAL",
-  "2020_01_NYJ_BUF",
-  "2020_01_LV_CAR",
-  "2020_01_CHI_DET",
-  "2020_01_IND_JAX",
-  "2020_01_GB_MIN",
-  "2020_01_MIA_NE",
-  "2020_01_PHI_WAS",
-  "2020_01_LAC_CIN",
-  "2020_01_TB_NO",
   "2020_01_ARI_SF",
+  "2020_01_CHI_DET",
+  "2020_01_CLE_BAL",
   "2020_01_DAL_LA",
+  "2020_01_GB_MIN",
+  "2020_01_HOU_KC",
+  "2020_01_IND_JAX",
+  "2020_01_LAC_CIN",
+  "2020_01_LV_CAR",
+  "2020_01_MIA_NE",
+  "2020_01_NYJ_BUF",
+  "2020_01_PHI_WAS",
   "2020_01_PIT_NYG",
+  "2020_01_SEA_ATL",
+  "2020_01_TB_NO",
   "2020_01_TEN_DEN",
-  "2020_02_CIN_CLE",
-  "2020_02_NYG_CHI",
   "2020_02_ATL_DAL",
-  "2020_02_DET_GB",
-  "2020_02_MIN_IND",
-  "2020_02_BUF_MIA",
-  "2020_02_SF_NYJ",
-  "2020_02_LA_PHI",
-  "2020_02_DEN_PIT",
-  "2020_02_CAR_TB",
-  "2020_02_JAX_TEN",
-  "2020_02_WAS_ARI",
   "2020_02_BAL_HOU",
+  "2020_02_BUF_MIA",
+  "2020_02_CAR_TB",
+  "2020_02_CIN_CLE",
+  "2020_02_DEN_PIT",
+  "2020_02_DET_GB",
+  "2020_02_JAX_TEN",
   "2020_02_KC_LAC",
+  "2020_02_LA_PHI",
+  "2020_02_MIN_IND",
   "2020_02_NE_SEA",
   "2020_02_NO_LV",
-  "2020_03_MIA_JAX",
-  "2020_03_CHI_ATL",
-  "2020_03_LA_BUF",
-  "2020_03_WAS_CLE",
-  "2020_03_TEN_MIN",
-  "2020_03_LV_NE",
-  "2020_03_SF_NYG",
-  "2020_03_CIN_PHI",
-  "2020_03_HOU_PIT",
-  "2020_03_NYJ_IND",
+  "2020_02_NYG_CHI",
+  "2020_02_SF_NYJ",
+  "2020_02_WAS_ARI",
   "2020_03_CAR_LAC",
-  "2020_03_DET_ARI",
-  "2020_03_TB_DEN",
+  "2020_03_CHI_ATL",
+  "2020_03_CIN_PHI",
   "2020_03_DAL_SEA",
+  "2020_03_DET_ARI",
   "2020_03_GB_NO",
+  "2020_03_HOU_PIT",
   "2020_03_KC_BAL",
-  "2020_04_DEN_NYJ",
+  "2020_03_LA_BUF",
+  "2020_03_LV_NE",
+  "2020_03_MIA_JAX",
+  "2020_03_NYJ_IND",
+  "2020_03_SF_NYG",
+  "2020_03_TB_DEN",
+  "2020_03_TEN_MIN",
+  "2020_03_WAS_CLE",
   "2020_04_ARI_CAR",
+  "2020_04_ATL_GB",
+  "2020_04_BAL_WAS",
+  "2020_04_BUF_LV",
+  "2020_04_CLE_DAL",
+  "2020_04_DEN_NYJ",
   "2020_04_IND_CHI",
   "2020_04_JAX_CIN",
-  "2020_04_CLE_DAL",
-  "2020_04_NO_DET",
-  "2020_04_MIN_HOU",
-  "2020_04_SEA_MIA",
   "2020_04_LAC_TB",
-  "2020_04_PIT_TEN",
-  "2020_04_BAL_WAS",
-  "2020_04_NYG_LA",
+  "2020_04_MIN_HOU",
   "2020_04_NE_KC",
-  "2020_04_BUF_LV",
+  "2020_04_NO_DET",
+  "2020_04_NYG_LA",
   "2020_04_PHI_SF",
-  "2020_04_ATL_GB",
-  "2020_05_TB_CHI",
+  "2020_04_SEA_MIA",
+  "2020_05_ARI_NYJ",
+  "2020_05_BUF_TEN",
   "2020_05_CAR_ATL",
   "2020_05_CIN_BAL",
-  "2020_05_JAX_HOU",
-  "2020_05_LV_KC",
-  "2020_05_DEN_NE",
-  "2020_05_ARI_NYJ",
-  "2020_05_PHI_PIT",
-  "2020_05_BUF_TEN",
-  "2020_05_LA_WAS",
-  "2020_05_MIA_SF",
   "2020_05_IND_CLE",
-  "2020_05_NYG_DAL",
-  "2020_05_MIN_SEA",
+  "2020_05_JAX_HOU",
   "2020_05_LAC_NO",
-  "2020_06_KC_BUF",
+  "2020_05_LA_WAS",
+  "2020_05_LV_KC",
+  "2020_05_MIA_SF",
+  "2020_05_MIN_SEA",
+  "2020_05_NYG_DAL",
+  "2020_05_PHI_PIT",
+  "2020_05_TB_CHI",
+  "2020_06_ARI_DAL",
+  "2020_06_ATL_MIN",
+  "2020_06_BAL_PHI",
   "2020_06_CHI_CAR",
   "2020_06_CIN_IND",
-  "2020_06_DET_JAX",
-  "2020_06_ATL_MIN",
-  "2020_06_WAS_NYG",
-  "2020_06_BAL_PHI",
   "2020_06_CLE_PIT",
-  "2020_06_HOU_TEN",
-  "2020_06_MIA_DEN",
-  "2020_06_NYJ_LAC",
+  "2020_06_DEN_NE",
+  "2020_06_DET_JAX",
   "2020_06_GB_TB",
+  "2020_06_HOU_TEN",
+  "2020_06_KC_BUF",
   "2020_06_LA_SF",
-  "2020_06_ARI_DAL",
-  "2020_07_NYG_PHI",
-  "2020_07_DET_ATL",
-  "2020_07_PIT_BAL",
-  "2020_07_CLE_CIN",
-  "2020_07_GB_HOU",
-  "2020_07_LAC_MIA",
-  "2020_07_CAR_NO",
+  "2020_06_NYJ_MIA",
+  "2020_06_WAS_NYG",
   "2020_07_BUF_NYJ",
+  "2020_07_CAR_NO",
+  "2020_07_CHI_LA",
+  "2020_07_CLE_CIN",
   "2020_07_DAL_WAS",
-  "2020_07_SEA_ARI",
+  "2020_07_DET_ATL",
+  "2020_07_GB_HOU",
+  "2020_07_JAX_LAC",
   "2020_07_KC_DEN",
+  "2020_07_NYG_PHI",
+  "2020_07_PIT_TEN",
+  "2020_07_SEA_ARI",
   "2020_07_SF_NE",
   "2020_07_TB_LV",
-  "2020_07_CHI_LA",
   "2020_08_ATL_CAR",
-  "2020_08_NE_BUF",
-  "2020_08_TEN_CIN",
-  "2020_08_LV_CLE",
-  "2020_08_IND_DET",
-  "2020_08_MIN_GB",
-  "2020_08_NYJ_KC",
-  "2020_08_LA_MIA",
-  "2020_08_JAX_LAC",
-  "2020_08_NO_CHI",
-  "2020_08_SF_SEA",
   "2020_08_DAL_PHI",
+  "2020_08_IND_DET",
+  "2020_08_LAC_DEN",
+  "2020_08_LA_MIA",
+  "2020_08_LV_CLE",
+  "2020_08_MIN_GB",
+  "2020_08_NE_BUF",
+  "2020_08_NO_CHI",
+  "2020_08_NYJ_KC",
+  "2020_08_PIT_BAL",
+  "2020_08_SF_SEA",
   "2020_08_TB_NYG",
-  "2020_09_GB_SF",
-  "2020_09_DEN_ATL",
-  "2020_09_SEA_BUF",
+  "2020_08_TEN_CIN",
   "2020_09_BAL_IND",
-  "2020_09_HOU_JAX",
   "2020_09_CAR_KC",
-  "2020_09_DET_MIN",
   "2020_09_CHI_TEN",
-  "2020_09_NYG_WAS",
+  "2020_09_DEN_ATL",
+  "2020_09_DET_MIN",
+  "2020_09_GB_SF",
+  "2020_09_HOU_JAX",
   "2020_09_LV_LAC",
   "2020_09_MIA_ARI",
-  "2020_09_PIT_DAL",
-  "2020_09_NO_TB",
   "2020_09_NE_NYJ",
-  "2020_10_IND_TEN",
-  "2020_10_TB_CAR",
-  "2020_10_HOU_CLE",
-  "2020_10_WAS_DET",
-  "2020_10_JAX_GB",
-  "2020_10_PHI_NYG",
-  "2020_10_CIN_PIT",
+  "2020_09_NO_TB",
+  "2020_09_NYG_WAS",
+  "2020_09_PIT_DAL",
+  "2020_09_SEA_BUF",
+  "2020_10_BAL_NE",
   "2020_10_BUF_ARI",
+  "2020_10_CIN_PIT",
   "2020_10_DEN_LV",
-  "2020_10_NYJ_MIA",
+  "2020_10_HOU_CLE",
+  "2020_10_IND_TEN",
+  "2020_10_JAX_GB",
+  "2020_10_LAC_MIA",
+  "2020_10_MIN_CHI",
+  "2020_10_PHI_NYG",
   "2020_10_SEA_LA",
   "2020_10_SF_NO",
-  "2020_10_BAL_NE",
-  "2020_10_MIN_CHI",
+  "2020_10_TB_CAR",
+  "2020_10_WAS_DET",
   "2020_11_ARI_SEA",
-  "2020_11_TEN_BAL",
-  "2020_11_DET_CAR",
-  "2020_11_PHI_CLE",
-  "2020_11_NE_HOU",
-  "2020_11_GB_IND",
-  "2020_11_PIT_JAX",
   "2020_11_ATL_NO",
   "2020_11_CIN_WAS",
-  "2020_11_LAC_DEN",
   "2020_11_DAL_MIN",
+  "2020_11_DET_CAR",
+  "2020_11_GB_IND",
   "2020_11_KC_LV",
   "2020_11_LA_TB",
-  "2020_12_HOU_DET",
-  "2020_12_WAS_DAL",
-  "2020_12_BAL_PIT",
-  "2020_12_LV_ATL",
-  "2020_12_LAC_BUF",
-  "2020_12_NYG_CIN",
-  "2020_12_TEN_IND",
-  "2020_12_CLE_JAX",
-  "2020_12_CAR_MIN",
+  "2020_11_MIA_DEN",
+  "2020_11_NE_HOU",
+  "2020_11_NYJ_LAC",
+  "2020_11_PHI_CLE",
+  "2020_11_PIT_JAX",
+  "2020_11_TEN_BAL",
   "2020_12_ARI_NE",
+  "2020_12_BAL_PIT",
+  "2020_12_CAR_MIN",
+  "2020_12_CHI_GB",
+  "2020_12_CLE_JAX",
+  "2020_12_HOU_DET",
+  "2020_12_KC_TB",
+  "2020_12_LAC_BUF",
+  "2020_12_LV_ATL",
   "2020_12_MIA_NYJ",
   "2020_12_NO_DEN",
-  "2020_12_SF_LA",
-  "2020_12_KC_TB",
-  "2020_12_CHI_GB",
+  "2020_12_NYG_CIN",
   "2020_12_SEA_PHI",
+  "2020_12_SF_LA",
+  "2020_12_TEN_IND",
+  "2020_12_WAS_DAL",
+  "2020_13_BUF_SF",
+  "2020_13_CIN_MIA",
+  "2020_13_CLE_TEN",
   "2020_13_DAL_BAL",
-  "2020_13_NO_ATL",
+  "2020_13_DEN_KC",
   "2020_13_DET_CHI",
   "2020_13_IND_HOU",
-  "2020_13_CIN_MIA",
   "2020_13_JAX_MIN",
-  "2020_13_LV_NYJ",
-  "2020_13_WAS_PIT",
-  "2020_13_CLE_TEN",
   "2020_13_LA_ARI",
+  "2020_13_LV_NYJ",
+  "2020_13_NE_LAC",
+  "2020_13_NO_ATL",
   "2020_13_NYG_SEA",
   "2020_13_PHI_GB",
-  "2020_13_NE_LAC",
-  "2020_13_DEN_KC",
-  "2020_13_BUF_SF",
-  "2020_14_NE_LA",
-  "2020_14_DEN_CAR",
-  "2020_14_HOU_CHI",
-  "2020_14_DAL_CIN",
-  "2020_14_GB_DET",
-  "2020_14_TEN_JAX",
-  "2020_14_KC_MIA",
+  "2020_13_WAS_PIT",
   "2020_14_ARI_NYG",
-  "2020_14_MIN_TB",
-  "2020_14_IND_LV",
-  "2020_14_NYJ_SEA",
   "2020_14_ATL_LAC",
-  "2020_14_NO_PHI",
-  "2020_14_WAS_SF",
-  "2020_14_PIT_BUF",
   "2020_14_BAL_CLE",
-  "2020_15_LAC_LV",
-  "2020_15_TB_ATL",
-  "2020_15_JAX_BAL",
+  "2020_14_DAL_CIN",
+  "2020_14_DEN_CAR",
+  "2020_14_GB_DET",
+  "2020_14_HOU_CHI",
+  "2020_14_IND_LV",
+  "2020_14_KC_MIA",
+  "2020_14_MIN_TB",
+  "2020_14_NE_LA",
+  "2020_14_NO_PHI",
+  "2020_14_NYJ_SEA",
+  "2020_14_PIT_BUF",
+  "2020_14_TEN_JAX",
+  "2020_14_WAS_SF",
   "2020_15_BUF_DEN",
   "2020_15_CAR_GB",
-  "2020_15_HOU_IND",
-  "2020_15_NYJ_LA",
-  "2020_15_NE_MIA",
   "2020_15_CHI_MIN",
   "2020_15_CLE_NYG",
   "2020_15_DET_TEN",
-  "2020_15_SEA_WAS",
-  "2020_15_PHI_ARI",
+  "2020_15_HOU_IND",
+  "2020_15_JAX_BAL",
   "2020_15_KC_NO",
-  "2020_15_SF_DAL",
+  "2020_15_LAC_LV",
+  "2020_15_NE_MIA",
+  "2020_15_NYJ_LA",
+  "2020_15_PHI_ARI",
   "2020_15_PIT_CIN",
-  "2020_16_MIN_NO",
-  "2020_16_SF_ARI",
-  "2020_16_NYG_BAL",
-  "2020_16_TB_DET",
-  "2020_16_CIN_HOU",
-  "2020_16_CHI_JAX",
+  "2020_15_SEA_WAS",
+  "2020_15_SF_DAL",
+  "2020_15_TB_ATL",
   "2020_16_ATL_KC",
-  "2020_16_DEN_LAC",
-  "2020_16_MIA_LV",
-  "2020_16_CLE_NYJ",
-  "2020_16_IND_PIT",
-  "2020_16_CAR_WAS",
-  "2020_16_LA_SEA",
-  "2020_16_PHI_DAL",
-  "2020_16_TEN_GB",
   "2020_16_BUF_NE",
-  "2020_17_MIA_BUF",
-  "2020_17_NO_CAR",
-  "2020_17_GB_CHI",
+  "2020_16_CAR_WAS",
+  "2020_16_CHI_JAX",
+  "2020_16_CIN_HOU",
+  "2020_16_CLE_NYJ",
+  "2020_16_DEN_LAC",
+  "2020_16_IND_PIT",
+  "2020_16_LA_SEA",
+  "2020_16_MIA_LV",
+  "2020_16_MIN_NO",
+  "2020_16_NYG_BAL",
+  "2020_16_PHI_DAL",
+  "2020_16_SF_ARI",
+  "2020_16_TB_DET",
+  "2020_16_TEN_GB",
+  "2020_17_ARI_LA",
+  "2020_17_ATL_TB",
   "2020_17_BAL_CIN",
-  "2020_17_PIT_CLE",
-  "2020_17_MIN_DET",
-  "2020_17_TEN_HOU",
+  "2020_17_DAL_NYG",
+  "2020_17_GB_CHI",
   "2020_17_JAX_IND",
   "2020_17_LAC_KC",
-  "2020_17_NYJ_NE",
-  "2020_17_DAL_NYG",
-  "2020_17_WAS_PHI",
-  "2020_17_ATL_TB",
   "2020_17_LV_DEN",
-  "2020_17_ARI_LA",
-  "2020_17_SEA_SF"
+  "2020_17_MIA_BUF",
+  "2020_17_MIN_DET",
+  "2020_17_NO_CAR",
+  "2020_17_NYJ_NE",
+  "2020_17_PIT_CLE",
+  "2020_17_SEA_SF",
+  "2020_17_TEN_HOU",
+  "2020_17_WAS_PHI"
 )
